@@ -3,7 +3,7 @@ use Moose;
 
 use MooseX::Storage;
 
-with Storage(format => 'JSON', io => 'File');
+with 'MooseX::Storage::Deferred';
 
 extends 'Data::Paginator';
 
